@@ -4,7 +4,7 @@ Main interface for codeartifact service.
 Usage::
 
     ```python
-    import boto3
+    from boto3.session import Session
     from mypy_boto3_codeartifact import (
         Client,
         CodeArtifactClient,
@@ -16,10 +16,8 @@ Usage::
         ListRepositoriesPaginator,
     )
 
-    session = boto3.Session()
-
-    client: CodeArtifactClient = boto3.client("codeartifact")
-    session_client: CodeArtifactClient = session.client("codeartifact")
+    session = Session()
+    client: CodeArtifactClient = session.client("codeartifact")
 
     list_domains_paginator: ListDomainsPaginator = client.get_paginator("list_domains")
     list_package_version_assets_paginator: ListPackageVersionAssetsPaginator = client.get_paginator("list_package_version_assets")
