@@ -1,14 +1,14 @@
 """
 Type annotations for codeartifact service literal definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeartifact/literals.html)
+[Open documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_codeartifact/literals/)
 
 Usage::
 
     ```python
-    from mypy_boto3_codeartifact.literals import DomainStatusType
+    from mypy_boto3_codeartifact.literals import AllowPublishType
 
-    data: DomainStatusType = "Active"
+    data: AllowPublishType = "ALLOW"
     ```
 """
 import sys
@@ -20,6 +20,8 @@ else:
 
 
 __all__ = (
+    "AllowPublishType",
+    "AllowUpstreamType",
     "DomainStatusType",
     "ExternalConnectionStatusType",
     "HashAlgorithmType",
@@ -31,15 +33,19 @@ __all__ = (
     "ListRepositoriesPaginatorName",
     "PackageFormatType",
     "PackageVersionErrorCodeType",
+    "PackageVersionOriginTypeType",
     "PackageVersionSortTypeType",
     "PackageVersionStatusType",
     "CodeArtifactServiceName",
     "ServiceName",
     "ResourceServiceName",
     "PaginatorName",
+    "RegionName",
 )
 
 
+AllowPublishType = Literal["ALLOW", "BLOCK"]
+AllowUpstreamType = Literal["ALLOW", "BLOCK"]
 DomainStatusType = Literal["Active", "Deleted"]
 ExternalConnectionStatusType = Literal["Available"]
 HashAlgorithmType = Literal["MD5", "SHA-1", "SHA-256", "SHA-512"]
@@ -58,6 +64,7 @@ PackageVersionErrorCodeType = Literal[
     "NOT_FOUND",
     "SKIPPED",
 ]
+PackageVersionOriginTypeType = Literal["EXTERNAL", "INTERNAL", "UNKNOWN"]
 PackageVersionSortTypeType = Literal["PUBLISHED_TIME"]
 PackageVersionStatusType = Literal[
     "Archived", "Deleted", "Disposed", "Published", "Unfinished", "Unlisted"
@@ -100,6 +107,7 @@ ServiceName = Literal[
     "ce",
     "chime",
     "chime-sdk-identity",
+    "chime-sdk-media-pipelines",
     "chime-sdk-meetings",
     "chime-sdk-messaging",
     "cloud9",
@@ -132,6 +140,7 @@ ServiceName = Literal[
     "config",
     "connect",
     "connect-contact-lens",
+    "connectcampaigns",
     "connectparticipant",
     "cur",
     "customer-profiles",
@@ -168,6 +177,7 @@ ServiceName = Literal[
     "elbv2",
     "emr",
     "emr-containers",
+    "emr-serverless",
     "es",
     "events",
     "evidently",
@@ -181,6 +191,7 @@ ServiceName = Literal[
     "frauddetector",
     "fsx",
     "gamelift",
+    "gamesparks",
     "glacier",
     "globalaccelerator",
     "glue",
@@ -214,6 +225,7 @@ ServiceName = Literal[
     "iottwinmaker",
     "iotwireless",
     "ivs",
+    "ivschat",
     "kafka",
     "kafkaconnect",
     "kendra",
@@ -239,6 +251,7 @@ ServiceName = Literal[
     "lookoutequipment",
     "lookoutmetrics",
     "lookoutvision",
+    "m2",
     "machinelearning",
     "macie",
     "macie2",
@@ -282,6 +295,7 @@ ServiceName = Literal[
     "pinpoint",
     "pinpoint-email",
     "pinpoint-sms-voice",
+    "pinpoint-sms-voice-v2",
     "polly",
     "pricing",
     "proton",
@@ -294,11 +308,13 @@ ServiceName = Literal[
     "rds-data",
     "redshift",
     "redshift-data",
+    "redshift-serverless",
     "rekognition",
     "resiliencehub",
     "resource-groups",
     "resourcegroupstaggingapi",
     "robomaker",
+    "rolesanywhere",
     "route53",
     "route53-recovery-cluster",
     "route53-recovery-control-config",
@@ -386,3 +402,18 @@ PaginatorName = Literal[
     "list_repositories",
     "list_repositories_in_domain",
 ]
+RegionName = Literal[
+    "ap-northeast-1",
+    "ap-south-1",
+    "ap-southeast-1",
+    "ap-southeast-2",
+    "eu-central-1",
+    "eu-north-1",
+    "eu-south-1",
+    "eu-west-1",
+    "eu-west-2",
+    "eu-west-3",
+    "us-east-1",
+    "us-east-2",
+    "us-west-2",
+]
